@@ -131,7 +131,7 @@ def match_previous_literal(expr: ParserElement) -> ParserElement:
         rep << And(Literal(tt) for tt in tflat)
 
     expr.add_parse_action(copy_token_to_repeater, call_during_try=True)
-    rep.set_name("(prev) " + str(expr))
+    rep.set_name(f"(prev) {expr}")
     return rep
 
 
@@ -169,7 +169,7 @@ def match_previous_expr(expr: ParserElement) -> ParserElement:
         rep.set_parse_action(must_match_these_tokens, call_during_try=True)
 
     expr.add_parse_action(copy_token_to_repeater, call_during_try=True)
-    rep.set_name("(prev) " + str(expr))
+    rep.set_name(f"(prev) {expr}")
     return rep
 
 
@@ -229,6 +229,7 @@ def one_of(
             "warn_on_multiple_string_args_to_oneof:"
             " More than one string argument passed to one_of, pass"
             " choices as a list or space-delimited string",
+            PyparsingDiagnosticWarning,
             stacklevel=2,
         )
 
@@ -293,7 +294,9 @@ def one_of(
 
         except re.error:
             warnings.warn(
-                "Exception creating Regex for one_of, building MatchFirst", stacklevel=2
+                "Exception creating Regex for one_of, building MatchFirst",
+                PyparsingDiagnosticWarning,
+                stacklevel=2,
             )
 
     # last resort, just use MatchFirst of Token class corresponding to caseless
@@ -453,7 +456,7 @@ def locatedExpr(expr: ParserElement) -> ParserElement:
     """
     warnings.warn(
         f"{'locatedExpr'!r} deprecated - use {'Located'!r}",
-        DeprecationWarning,
+        PyparsingDeprecationWarning,
         stacklevel=2,
     )
 
@@ -1077,7 +1080,7 @@ def indentedBlock(blockStatementExpr, indentStack, indent=True, backup_stacks=[]
     """
     warnings.warn(
         f"{'indentedBlock'!r} deprecated - use {'IndentedBlock'!r}",
-        DeprecationWarning,
+        PyparsingDeprecationWarning,
         stacklevel=2,
     )
 
